import numpy as np
import sklearn.datasets as samples_generator
from sklearn import model_selection
from sklearn import metrics
from sklearn.neural_network import MLPClassifier
import matplotlib.pyplot as plt

X, y = samples_generator.make_circles( noise=0.1, factor=0.35, random_state=9 )
# print( X.shape )
# print( y )

# Separamos los datos de entrenamiento y de prueba
Xentrena, Xprueba, yentrena, yprueba = model_selection.train_test_split( X, y, test_size = 0.2, random_state = 20 )

# np.savetxt( "Xprueba.txt", Xprueba )
# np.savetxt( "yprueba.txt", yprueba )

red = MLPClassifier(solver='lbfgs', alpha=1e-5, hidden_layer_sizes=(5,), random_state=1)

red.fit( Xentrena, yentrena )

ypredichas = red.predict( Xentrena )
exactitud = metrics.accuracy_score( yentrena, ypredichas )
print( "Entrenamiento:", exactitud )

ypredichas = red.predict( Xprueba )
e = metrics.accuracy_score( yprueba, ypredichas )
print( "Prueba:", e )
# print( ypredichas )

print( red.get_params() )
for coef in red.coefs_ :
	print( coef.shape )

for coef in red.coefs_ :
	print( coef )

print( type(red) )
print( red.intercepts_ )
print( red.out_activation_ )

# Graficamos los resultados

fig, [ex1, ex2] = plt.subplots( 1, 2 )

# Los datos de entrenamiento
ex1.scatter( Xentrena[:,0], Xentrena[:,1], c=yentrena )
ex1.set_aspect( 1.0 )
xmin, xmax = ex1.get_xlim( )
ymin, ymax = ex1.get_ylim( )

# Los datos de prueba
ex2.scatter( Xprueba[:,0], Xprueba[:,1], c=yprueba )
ex2.set_aspect( 1.0 )
ex2.set_xlim( xmin, xmax )
ex2.set_ylim( ymin, ymax )

plt.show( )
